svn commit: r241369 - in head/sys: dev/arcmsr netgraph/netflow netpfil/ipfw
Kevin Lo
kevlo at FreeBSD.org
Tue Oct 9 06:32:27 UTC 2012
Author: kevlo
Date: Tue Oct 9 06:15:16 2012
New Revision: 241369
URL: http://svn.freebsd.org/changeset/base/241369
Log:
Fix typo: s/unknow/unknown
Modified:
head/sys/dev/arcmsr/arcmsr.c
head/sys/netgraph/netflow/ng_netflow.c
head/sys/netpfil/ipfw/ip_dn_glue.c
Modified: head/sys/dev/arcmsr/arcmsr.c
==============================================================================
--- head/sys/netgraph/netflow/ng_netflow.c Tue Oct 9 05:06:30 2012 (r241368)
+++ head/sys/netgraph/netflow/ng_netflow.c Tue Oct 9 06:15:16 2012 (r241369)
@@ -832,7 +832,7 @@ ng_netflow_rcvdata (hook_p hook, item_p
goto loopend;
#endif
/*
- * Any unknow header (new extension or IPv6/IPv4
+ * Any unknown header (new extension or IPv6/IPv4
* header for tunnels) ends loop.
*/
default:
Modified: head/sys/netpfil/ipfw/ip_dn_glue.c
==============================================================================
--- head/sys/netpfil/ipfw/ip_dn_glue.c Tue Oct 9 05:06:30 2012 (r241368)
+++ head/sys/netpfil/ipfw/ip_dn_glue.c Tue Oct 9 06:15:16 2012 (r241369)
@@ -315,10 +315,10 @@ static size_t pipesizemax8 = sizeof(stru
/* Indicate 'ipfw' version
* 1: from FreeBSD 7.2
* 0: from FreeBSD 8
- * -1: unknow (for now is unused)
+ * -1: unknown (for now is unused)
*
* It is update when a IP_DUMMYNET_DEL or IP_DUMMYNET_CONFIGURE request arrives
- * NOTE: if a IP_DUMMYNET_GET arrives and the 'ipfw' version is unknow,
+ * NOTE: if a IP_DUMMYNET_GET arrives and the 'ipfw' version is unknown,
* it is suppose to be the FreeBSD 8 version.
*/
static int is7 = 0;
More information about the svn-src-all
mailing list
--- head/sys/dev/arcmsr/arcmsr.c Tue Oct 9 05:06:30 2012 (r241368)
+++ head/sys/dev/arcmsr/arcmsr.c Tue Oct 9 06:15:16 2012 (r241369)
@@ -753,11 +753,11 @@ static void arcmsr_report_srb_state(stru
}
break;
default:
- printf("arcmsr%d: scsi id=%d lun=%d isr got command error done,but got unknow DeviceStatus=0x%x \n"
+ printf("arcmsr%d: scsi id=%d lun=%d isr got command error done,but got unknown DeviceStatus=0x%x \n"
, acb->pci_unit, target, lun ,srb->arcmsr_cdb.DeviceStatus);
acb->devstate[target][lun]=ARECA_RAID_GONE;
srb->pccb->ccb_h.status |= CAM_UNCOR_PARITY;
/*unknow error or crc error just for retry*/
arcmsr_srb_complete(srb, 1);
break;
}
@@ -1789,7 +1789,7 @@ static void arcmsr_interrupt(struct Adap
break;
default:
printf("arcmsr%d: interrupt service,"
- " unknow adapter type =%d\n", acb->pci_unit, acb->adapter_type);
+ " unknown adapter type =%d\n", acb->pci_unit, acb->adapter_type);
break;
}
}
@@ -753,11 +753,11 @@ static void arcmsr_report_srb_state(stru
acb->devstate[target][lun]=ARECA_RAID_GONE;
srb->pccb->ccb_h.status |= CAM_UNCOR_PARITY;
- /*unknow error or crc error just for retry*/
+ /*unknown error or crc error just for retry*/
arcmsr_srb_complete(srb, 1);
break;
Modified: head/sys/netgraph/netflow/ng_netflow.c
==============================================================================